@@ -14,7 +14,9 @@
 #include "kicondialog_p.h"
 #include "kicondialogmodel_p.h"
 
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
+#include <KStandardAction>
 
 #include <QAbstractListModel>
 #include <QApplication>
@@ -301,20 +303,22 @@ void KIconDialogPrivate::init()
     QObject::connect(proxyModel, &QSortFilterProxyModel::rowsInserted, q, updatePlaceholder);
     QObject::connect(proxyModel, &QSortFilterProxyModel::rowsRemoved, q, updatePlaceholder);
 
-    // TODO set Ctrl+F shortcut
+    QAction *findAction = KStandardAction::find(ui.searchLine, qOverload<>(&QWidget::setFocus), q);
+    q->addAction(findAction);
+
     QObject::connect(ui.searchLine, &QLineEdit::textChanged, proxyModel, &QSortFilterProxyModel::setFilterFixedString);
 
-    static const char *const context_text[] = {
-        I18N_NOOP("All"),
-        I18N_NOOP("Actions"),
-        I18N_NOOP("Applications"),
-        I18N_NOOP("Categories"),
-        I18N_NOOP("Devices"),
-        I18N_NOOP("Emblems"),
-        I18N_NOOP("Emotes"),
-        I18N_NOOP("Mimetypes"),
-        I18N_NOOP("Places"),
-        I18N_NOOP("Status"),
+    static const KLazyLocalizedString context_text[] = {
+        kli18n("All"),
+        kli18n("Actions"),
+        kli18n("Applications"),
+        kli18n("Categories"),
+        kli18n("Devices"),
+        kli18n("Emblems"),
+        kli18n("Emotes"),
+        kli18n("Mimetypes"),
+        kli18n("Places"),
+        kli18n("Status"),
     };
     static const KIconLoader::Context context_id[] = {
         KIconLoader::Any,
@@ -331,7 +335,7 @@ void KIconDialogPrivate::init()
     const int cnt = sizeof(context_text) / sizeof(context_text[0]);
     for (int i = 0; i < cnt; ++i) {
         if (mpLoader->hasContext(context_id[i])) {
-            ui.contextCombo->addItem(i18n(context_text[i]), context_id[i]);
+            ui.contextCombo->addItem(context_text[i].toString(), context_id[i]);
             if (i == 0) {
                 ui.contextCombo->insertSeparator(i + 1);
             }
@@ -473,6 +477,31 @@ void KIconDialogPrivate::showIcons()
     model->setIconSize(ui.canvas->iconSize());
     model->setDevicePixelRatio(q->devicePixelRatioF());
     model->load(filelist);
+
+    if (!pendingSelectedIcon.isEmpty()) {
+        selectIcon(pendingSelectedIcon);
+        pendingSelectedIcon.clear();
+    }
+}
+
+bool KIconDialogPrivate::selectIcon(const QString &iconName)
+{
+    for (int i = 0; i < proxyModel->rowCount(); ++i) {
+        const QModelIndex idx = proxyModel->index(i, 0);
+
+        QString name = idx.data(KIconDialogModel::PathRole).toString();
+        if (!name.isEmpty() && isSystemIconsContext()) {
+            const QFileInfo fi(name);
+            name = fi.completeBaseName();
+        }
+
+        if (iconName == name) {
+            ui.canvas->setCurrentIndex(idx);
+            return true;
+        }
+    }
+
+    return false;
 }
 
 void KIconDialog::setStrictIconSize(bool b)
@@ -501,6 +530,12 @@ int KIconDialog::iconSize() const
     return (d->mGroupOrSize < 0) ? -d->mGroupOrSize : 0;
 }
 
+void KIconDialog::setSelectedIcon(const QString &iconName)
+{
+    // TODO Update live when dialog is already open
+    d->pendingSelectedIcon = iconName;
+}
+
 void KIconDialog::setup(KIconLoader::Group group, KIconLoader::Context context, bool strictIconSize, int iconSize, bool user, bool lockUser, bool lockCustomDir)
 {
     d->m_bStrictIconSize = strictIconSize;
