@@ -167,7 +167,7 @@ QString KIconThemePrivate::iconPath(const QVector<KIconThemeDir *> &dirs, const
 
     // Search the directory that contains the icon which matches best to the requested
     // size. If there is no directory which matches exactly to the requested size, the
-    // following criterias get applied:
+    // following criteria get applied:
     // - Take a directory having icons with a minimum difference to the requested size.
     // - Prefer directories that allow a downscaling even if the difference to
     //   the requested size is bigger than a directory where an upscaling is required.
@@ -285,7 +285,8 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
     // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
     icnlibs += QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("pixmaps"), QStandardPaths::LocateDirectory);
 
-    QString fileName, mainSection;
+    QString fileName;
+    QString mainSection;
     for (QStringList::ConstIterator it = icnlibs.constBegin(), total = icnlibs.constEnd(); it != total; ++it) {
         const QString cDir = *it + QLatin1Char('/') + name + QLatin1Char('/');
         if (QDir(cDir).exists()) {
@@ -541,10 +542,11 @@ QString KIconTheme::iconPathByName(const QString &iconName, int size, KIconLoade
 
 QString KIconTheme::iconPathByName(const QString &iconName, int size, KIconLoader::MatchType match, qreal scale) const
 {
-    for (const QString &current : qAsConst(d->mExtensions)) {
+    for (const QString &current : std::as_const(d->mExtensions)) {
         const QString path = iconPath(iconName + current, size, match, scale);
-        if (!path.isEmpty())
+        if (!path.isEmpty()) {
             return path;
+        }
     }
     return QString();
 }
@@ -630,7 +632,7 @@ QStringList KIconTheme::list()
     // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
     icnlibs += QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("pixmaps"), QStandardPaths::LocateDirectory);
 
-    for (const QString &it : qAsConst(icnlibs)) {
+    for (const QString &it : std::as_const(icnlibs)) {
         QDir dir(it);
         const QStringList lst = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
         for (QStringList::ConstIterator it2 = lst.begin(), total = lst.end(); it2 != total; ++it2) {
